@@ -61,6 +61,7 @@
 #include "skin/legacy/legacyskinparser.h"
 #include "skin/skinloader.h"
 #include "soundio/soundmanager.h"
+#include "soundio/soundmanagerconfig.h"
 #include "sources/soundsourceproxy.h"
 #include "track/track.h"
 #include "util/db/dbconnectionpooled.h"
@@ -234,9 +235,7 @@ MixxxMainWindow::MixxxMainWindow(QApplication* pApp, const CmdlineArgs& args)
 }
 
 MixxxMainWindow::~MixxxMainWindow() {
-    if (m_pDeveloperToolsDlg) {
-        delete m_pDeveloperToolsDlg;
-    }
+    delete m_pDeveloperToolsDlg;
     finalize();
     // SkinLoader depends on Config;
     delete m_pSkinLoader;
@@ -640,7 +639,9 @@ void MixxxMainWindow::initialize(QApplication* pApp, const CmdlineArgs& args) {
     // https://bugs.launchpad.net/mixxx/+bug/1758189
     m_pPlayerManager->loadSamplers();
 
-    // Try open player device If that fails, the preference panel is opened.
+    // Sound hardware setup
+    // Try to open configured devices. If that fails, display dialogs
+    // that allow to either retry, reconfigure devices or exit.
     bool retryClicked;
     do {
         retryClicked = false;
@@ -658,11 +659,10 @@ void MixxxMainWindow::initialize(QApplication* pApp, const CmdlineArgs& args) {
         }
     } while (retryClicked);
 
-    // test for at least one out device, if none, display another dlg that
-    // says "mixxx will barely work with no outs"
-    // In case persisting errors, the user has already received a message
-    // box from the preferences dialog above. So we can watch here just the
-    // output count.
+    // Test for at least one output device. If none, display another dialog
+    // that says "mixxx will barely work with no outs".
+    // In case of persisting errors, the user has already received a message
+    // above. So we can just check the output count here.
     while (m_pSoundManager->getConfig().getOutputs().count() == 0) {
         // Exit when we press the Exit button in the noSoundDlg dialog
         // only call it if result != OK
@@ -673,7 +673,10 @@ void MixxxMainWindow::initialize(QApplication* pApp, const CmdlineArgs& args) {
         if (continueClicked) {
             break;
         }
-   }
+    }
+    // The user has either reconfigured devices or accepted no outputs,
+    // so it's now safe to write the new config to disk.
+    m_pSoundManager->getConfig().writeToDisk();
 
     // Load tracks in args.qlMusicFiles (command line arguments) into player
     // 1 and 2:
@@ -710,7 +713,7 @@ void MixxxMainWindow::initialize(QApplication* pApp, const CmdlineArgs& args) {
 }
 
 void MixxxMainWindow::finalize() {
-    Timer t("MixxxMainWindow::~finalize");
+    Timer t("MixxxMainWindow::finalize");
     t.start();
 
     if (m_inhibitScreensaver != mixxx::ScreenSaverPreference::PREVENT_OFF) {
@@ -1035,6 +1038,7 @@ QDialog::DialogCode MixxxMainWindow::soundDeviceErrorDlg(
             m_pSoundManager->clearAndQueryDevices();
             // This way of opening the dialog allows us to use it synchronously
             m_pPrefDlg->setWindowModality(Qt::ApplicationModal);
+            // Open preferences, sound hardware page is selected (default on first call)
             m_pPrefDlg->exec();
             if (m_pPrefDlg->result() == QDialog::Accepted) {
                 return QDialog::Accepted;
