@@ -81,7 +81,10 @@ SoundManager::SoundManager(UserSettingsPointer pConfig,
         m_config.loadDefaults(this, SoundManagerConfig::ALL);
     }
     checkConfig();
-    m_config.writeToDisk(); // in case anything changed by applying defaults
+    // Don't write config to disk, yet -- it may be reset to defaults in case
+    // previously configured devices were not found.
+    // Write new config after MixxxMainWindow::noOutputDlg where the user has
+    // a chance to keep the previous sound config (exit).
 }
 
 SoundManager::~SoundManager() {
